@@ -1,12 +1,15 @@
 import asyncio
+import pop.hub
+from dict_tools import data
+from typing import Iterable, Dict, Any
 
 
 def __init__(hub):
     # Remember not to start your app in the __init__ function
     # This function should just be used to set up the plugin subsystem
     # Add another function to call from your run.py to start the app
-    hub.acct.SUB_PROFILES = {}
-    hub.acct.PROFILES = {}
+    hub.acct.SUB_PROFILES = data.NamespaceDict()
+    hub.acct.PROFILES = data.NamespaceDict()
     hub.acct.UNLOCKED = False
     hub.pop.sub.load_subdirs(hub.acct, recurse=True)
 
@@ -24,7 +27,7 @@ def unlock(hub, fn, key):
     Initialize the file read, then store the authentication data on the hub
     as hub.acct.PROFILES
     """
-    hub.acct.SUB_PROFILES = {}
+    hub.acct.SUB_PROFILES = data.NamespaceDict()
     hub.acct.PROFILES = hub.acct.enc.data_decrypt(fn, key)
 
     # If a profile has credentials for an external profile backend, unlock it now
@@ -43,15 +46,22 @@ def unlock(hub, fn, key):
     hub.acct.UNLOCKED = True
 
 
-async def gather(hub, subs, profile):
+async def gather(
+    hub, subs: Iterable[pop.hub.Sub], profile: Dict[str, Dict[str, Any]]
+) -> Dict[str, Dict[str, Any]]:
     """
     Given the named plugins and profile, execute the acct plugins to
     gather the needed profiles if data is not present for it.
     """
-    ret = {}
+    ret = data.NamespaceDict()
     if not hub.acct.UNLOCKED:
         hub.log.error("Account is locked")
         return ret
+
+    if not isinstance(subs, Iterable):
+        hub.log.warning(f"Unexpected type for sub: {subs.__class__}")
+        subs = []
+
     for sub in subs:
         sub_data = {}
         if sub in hub.acct.SUB_PROFILES:
